## Car Application

This is just a quick demonstration of ellar web framework. Modifications will be made on this project as the Ellar project 
evolves to become better.

## Installation
having setup up your virtual environment,
```shell
$(venv) poetry
```
## Project Setup
```shell
$(venv) poetry install
```

## Start Development Server
Start the dev server by running the code below:

```bash
ellar runserver --reload
```

Once the server is up, you can visit [SwaggerDoc](http://localhost:8000/docs#) or [ReDocs](http://localhost:8000/redoc#)
